@@ -10,6 +10,8 @@ password ="Administrator"
 server="85.214.60.83"
 port="8080"
 
+
+
 cube_upload_param={}
 # conn_det=None
 chg_log_from_date = "2022-11-01"
@@ -49,7 +51,11 @@ change_query={"chg_log_from_date":chg_log_from_date
               ,"mtdi_id":None
               ,"cube_name":"TestCube"}
 
+
+
 conn=mig.login(base_url=base_url,username=username,password=password,project_id="B19DEDCC11D4E0EFC000EB9495D0F44F")
+res=mig_rep.chk_chg_log_cols(conn=conn,report_id="454B29DF4872B9C74785A5A0A1A5FFB0")
+print(res)
 
 #pass over the parameters
 mig_rep.set_md_rep_params(conn=conn,change_query=change_query,change_log_report=change_log_report)
@@ -59,9 +65,17 @@ pd_df=mig_rep.get_mig_obj_logs()
 #reads out objects from pandas data frame
 df_obj=mig_rep.obj_id_from_df_l(pd_df,obj_col_ind=7,type_col_ind=10)
 
-#create short cuts from pandas data frame
+#create short cuts for change logs at level of user & object
+short_cut_df = pd_df.groupby(["USER_ID", "USER_LOGIN", "OBJECT_ID", "OBJECT_NAME", "OBJECT_TYPE"])[
+    "TRANSACTION_ID"].agg("count").reset_index()
+short_cut_df= mig_short_cut.bld_change_log_shortcut_df(conn=conn,short_cut_df=short_cut_df,change_log_df=pd_df)
 mig_short_cut.run_short_cut_build(conn=conn, project_id=change_query["short_cut_proj_id"],
-                                  chg_log_report_df=pd_df,folder_id=change_query["short_cut_folder_id"])
+                                  short_cut_df=short_cut_df,folder_id=change_query["short_cut_folder_id"],
+                                  object_id_col="OBJECT_ID",object_type_col="OBJECT_TYPE"
+                                  ,object_name_col="NEW_OBJECT_NAME",object_desc_col="OBJECT_DESC")
+
+#mig_short_cut.run_short_cut_build(conn=conn, project_id=change_query["short_cut_proj_id"],
+#                                  short_cut_df=short_cut_df,folder_id=change_query["short_cut_folder_id"],short_cut_col=short_cut_col)
 
 #export pandas change list to cube
 #pls note, that the structure of the cube
