@@ -49,47 +49,52 @@ class bld_short_cuts:
         self.rep = rep()
         self.glob = mstr_global()
 
+    def bld_change_log_shortcut_df(self,conn,short_cut_df,change_log_df):
+        #user_id,  object_id,object_name,object_type
+        short_cut_df["NEW_OBJECT_NAME"]=""
+        short_cut_df["DESC_STR"] = ""
+        for index, obj in short_cut_df.iterrows():
+            #short_cut_obj=self.glob.get_short_cut_obj(conn=conn, project_id="project_id",object_id=obj["OBJECT_ID"], type=18)
+            #builds the Strings for shortCut Name & Descriptions
+            #name user_login__object_name__object_guid
+            short_cut_df.at[index,"NEW_OBJECT_NAME"]  = obj["USER_LOGIN"]+ "__" + obj["OBJECT_NAME"] + "__" + obj["OBJECT_ID"]
+            short_cut_df.at[index, "OBJECT_DESC"]=self._bld_desc_str(change_log_df.loc[change_log_df["OBJECT_ID"] == obj["OBJECT_ID"]])
+        return short_cut_df
 
-
-    def bld_short_cut(self,conn,project_id,short_cut_col, folder_id,user_id,object_id,
-                      object_type,object_name):
+    def bld_short_cut(self,conn,project_id,folder_id,object_id,
+                      object_type,new_name,object_desc):
         #In Version 11 update 7, it's not possible to define a free name and description
         # when creating a short cut. Thus I create the shurt cut first and rename it later
         short_cut_obj_rep = self.glob._cr_short_cut(conn=conn,object_id=object_id,object_type=object_type,folder_id=folder_id)
-        #opens an instance of the create short cut object
+        #opens an instance of the created short cut object
         short_cut_obj=self.glob.get_short_cut_obj(conn=conn, project_id=project_id,
                                                   object_id=short_cut_obj_rep.json()["id"],
                                                   type=18)
-        #builds the Strings for shortCut Name & Descriptions
-        #name user_login__object_name__object_guid
-        new_name = user_id+ "__" + object_name + "__" + object_id
-        desc_str=self._bld_desc_str(short_cut_col.loc[short_cut_col["OBJECT_ID"] == object_id])
-        self.glob._rename_object(object=short_cut_obj, new_name=new_name, desc_str=desc_str)
+        self.glob._rename_object(object=short_cut_obj, new_name=new_name, desc_str=object_desc)
 
-    #@logger
-    def run_short_cut_build(self, conn,project_id,chg_log_report_df,folder_id):
+    def run_short_cut_build(self, conn,project_id,short_cut_df,folder_id,object_id_col,object_name_col,object_desc_col,object_type_col):
         #requiers a pandas data frame, based on the output of the change log report
         #here we count the number of changes at level of user & object
-        short_cut_col = chg_log_report_df.groupby(["USER_ID", "USER_LOGIN", "OBJECT_ID", "OBJECT_NAME", "OBJECT_TYPE"])[
-            "TRANSACTION_ID"].agg("count").reset_index()
+
         self.clean_shortcut_folder(conn=conn,project_id=project_id,folder_id=folder_id)
         short_cut_folder_j = f'{{"folderId": "{folder_id}"}}'
         #iterrating throuh all the objects in the list
-        short_cut_col.reset_index()
-        for index, obj in short_cut_col.iterrows():
+        short_cut_df.reset_index()
+        for index, obj in short_cut_df.iterrows():
             #short_cut_url = f'{conn.base_url}/objects/{obj[2]}/type/{str(obj[4])}/shortcuts'
             if obj[4]!=str(18):
                 self.bld_short_cut(conn=conn
                                    ,project_id=project_id
-                                   ,short_cut_col=short_cut_col
                                    ,folder_id=folder_id
-                                   ,user_id=obj[1]
-                                   ,object_id=obj[2]
-                                   ,object_name=obj[3]
-                                   ,object_type=obj[4])
+                                   ,object_id=obj[object_id_col]
+                                   ,object_type=obj[object_type_col]
+                                   ,new_name=obj[object_name_col]
+                                   ,object_desc=self.str._get_first_x_chars(str_=obj[object_desc_col],i=249)
+                                   )
             else:
                 print(f'Obect: {obj[2]} is a shortcut. MSTR does not allow short cuts o short cuts,'
                       f' thus they are not supported'  )
+
     #@logger
     def clean_shortcut_folder(self,conn,project_id,folder_id):
         #before adding new short cuts to the shortcut folder, all shortcuts gonna be deleted
@@ -108,13 +113,18 @@ class bld_short_cuts:
     def _bld_desc_str(self, all_changes=None):
         desc_str = ""
         all_changes_sum = all_changes.groupby(["USER_ID", "USER_LOGIN", "OBJECT_ID", "OBJECT_NAME", "OBJECT_TYPE"])[
-            "TRANSACTION_ID"].agg("sum").reset_index()
-        for index, s in all_changes.iterrows():
+            "TRANSACTION_ID"].agg("count").reset_index()
+        for index, s in all_changes_sum.iterrows():
             desc_str += s["USER_LOGIN"] + " (" + str(s["TRANSACTION_ID"]) + "), "
         return desc_str
 
 class get_change_log:
 
+    def __init__(self):
+        self.str= str_func()
+        self.rep = rep()
+        self.glob = mstr_global()
+
     def set_md_rep_params(self,conn,change_log_report,change_query):
         self.conn=conn
         self.chg_log_rep_proj_id = change_log_report["chg_log_rep_proj_id"]
@@ -131,10 +141,32 @@ class get_change_log:
         #self.chg_log_dep_bool = change_query["chg_log_dep_bool"]
         self.short_cut_folder_id=None
 
-        self.str= str_func()
-        self.rep = rep()
-        self.glob = mstr_global()
+    def parse_chglog_rep_cols(self,rep_def):
+        cols=[]
+        for r in rep_def.json()["definition"]["grid"]["rows"]:
+            if r["type"] == "attribute":
+                cols.append(r["name"])
+        return  cols
 
+    def chk_chg_log_cols(self,conn,report_id):
+        rep_def=self.rep.get_report_def(conn=conn,report_id=report_id)
+        cols= self.parse_chglog_rep_cols(rep_def)
+        return self.comp_col_chg_log_rep(cols)
+
+    def comp_col_chg_log_rep(self,cols):
+        original_col_order=["TRANSACTION_ID", "PROJECT_ID", "PROJECT_NAME", "USER_ID", "USER_LOGIN", "USERNAME", "COMMENT_VAL", "OBJECT_ID", "OBJECT_NAME", "SUBTYPE", "OBJECT_TYPE", "TRANSACTION_TIMESTAMP", "TRANSACTION_NAME", "TRANSACTION_TYPE", "TRANSACTION_SOURCE", "TRANSACTION_PROJECT_ID"]
+        comp_res={}
+        if original_col_order==cols:
+            comp_res["cols_ok_txt"]="Attributes names and order ok!"
+        else:
+            comp_res["number_of_cols_expected"] =   len(original_col_order)
+            comp_res["number_of_cols_provided"] =   len(cols)
+            comp_res["missing_cols"]=list(set(original_col_order) - set(cols))
+            comp_res["unkwon_cols"]=list(set(cols) - set(original_col_order))
+            comp_res["order_of_cols_expected"] =original_col_order
+            comp_res["order_of_cols_provided"] =cols
+
+        return comp_res
 
     def chg_rep_to_df(self,prompt_answ):
         instance_id = self.rep.open_Instance(conn=self.conn, project_id=self.short_cut_proj_id,
@@ -145,10 +177,7 @@ class get_change_log:
                                      prompt_answ=prompt_answ)
 
         rep_def=self.rep.get_report_def(conn=self.conn,report_id=self.chg_log_report_id)
-        cols=[]
-        for r in rep_def.json()["definition"]["grid"]["rows"]:
-            if r["type"] == "attribute":
-                cols.append(r["name"])
+        cols=self.parse_chglog_rep_cols(rep_def)
         cols.append("path")
 
         report_dict = self.rep.report_dict(conn=self.conn, project_id=self.short_cut_proj_id,
@@ -286,4 +315,5 @@ class searches:
                                                 obj_l=obj_id_l)
                     )
     def bld_df_from_search_result(self, conn,search_l):
-        return self.glob.bld_df_from_search_result(conn=conn, search_l=search_l)
\ No newline at end of file
+        return self.glob.bld_df_from_search_result(conn=conn, search_l=search_l)
+
