@@ -56,7 +56,7 @@ class rep:
         report_dict = self.i_parser.Parser(report_ds.json())._Parser__map_attributes(report_ds.json())
         return report_dict
 
-    @log(err_name="Failed to read out objects from Folder")
+    @log(err_name="Failed to read out report_definition")
     def get_report_def(self, conn, report_id):
         return self.i_reports.report_definition(connection=conn, report_id=report_id)
 
@@ -76,20 +76,14 @@ class mstr_global:
     @log(err_name="Failed to upload cube")
     def cube_upload(self, conn, load_df, tbl_name, updatePolicy="REPLACE", folder_id=None, cube_name=None,
                     mtdi_id=None):
-        print("Step1")
-        if mtdi_id == None:
+        if mtdi_id == None or mtdi_id =="":
             ds = SuperCube(connection=conn, name=cube_name)
-            print("Step2")
             ds.add_table(name=tbl_name, data_frame=load_df, update_policy=updatePolicy)
-            print("Step3")
             ds.create(folder_id=folder_id)
-            print("Step4")
-            mtdi_id = ds.id
         else:
             ds = SuperCube(connection=conn, id=mtdi_id)
             ds.add_table(name=tbl_name, data_frame=load_df, update_policy=updatePolicy)
             ds.update()
-            mtdi_id = ds.id
         return ds.id
 
     @log(err_name="Failed to read out objects from Folder")
